        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
}
