        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==5 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==40 && cc==3){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==41 && cc==3){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==42 && cc==3){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>1</strong> representante: <strong>31</strong> miembros: 26 <strong>control</strong><br>0,1,5,6,8,11,14,15,17,18,20,23,24,28,30,31,36,37,39,40,41,43,45,46,47,49';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>2</strong> representante: <strong>13</strong> miembros: 20 <br>2,3,4,7,9,10,12,13,16,19,21,25,27,29,32,33,34,35,38,48';}
       if(rr==43 && cc==3){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260614 a 12</strong> UTC HH+216 (rango:204-228)<br>grupo: <strong>3</strong> representante: <strong>50</strong> miembros: 5 <br>22,26,42,44,50';}
}
